==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/servicefabricmesh/kotlin/inputs/AutoScalingPolicyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicefabricmesh.kotlin.inputs

import com.pulumi.azurenative.servicefabricmesh.inputs.AutoScalingPolicyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Describes the auto scaling policy
 * @property mechanism The mechanism that is used to scale when auto scaling operation is invoked.
 * @property name The name of the auto scaling policy.
 * @property trigger Determines when auto scaling operation will be invoked.
 */
public data class AutoScalingPolicyArgs(
    public val mechanism: Output<AddRemoveReplicaScalingMechanismArgs>,
    public val name: Output<String>,
    public val trigger: Output<AverageLoadScalingTriggerArgs>,
) : ConvertibleToJava<com.pulumi.azurenative.servicefabricmesh.inputs.AutoScalingPolicyArgs> {
    override fun toJava(): com.pulumi.azurenative.servicefabricmesh.inputs.AutoScalingPolicyArgs =
        com.pulumi.azurenative.servicefabricmesh.inputs.AutoScalingPolicyArgs.builder()
            .mechanism(mechanism.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .name(name.applyValue({ args0 -> args0 }))
            .trigger(trigger.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [AutoScalingPolicyArgs].
 */
@PulumiTagMarker
public class AutoScalingPolicyArgsBuilder internal constructor() {
    private var mechanism: Output<AddRemoveReplicaScalingMechanismArgs>? = null

    private var name: Output<String>? = null

    private var trigger: Output<AverageLoadScalingTriggerArgs>? = null

    /**
     * @param value The mechanism that is used to scale when auto scaling operation is invoked.
     */
    @JvmName("bhdpmwtfocaxfjsy")
    public suspend fun mechanism(`value`: Output<AddRemoveReplicaScalingMechanismArgs>) {
        this.mechanism = value
    }

    /**
     * @param value The name of the auto scaling policy.
     */
    @JvmName("odbmrbrdukloqqvy")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Determines when auto scaling operation will be invoked.
     */
    @JvmName("lhgtmibvnbpyvyii")
    public suspend fun trigger(`value`: Output<AverageLoadScalingTriggerArgs>) {
        this.trigger = value
    }

    /**
     * @param value The mechanism that is used to scale when auto scaling operation is invoked.
     */
    @JvmName("bppytcdqdrrbsybm")
    public suspend fun mechanism(`value`: AddRemoveReplicaScalingMechanismArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.mechanism = mapped
    }

    /**
     * @param argument The mechanism that is used to scale when auto scaling operation is invoked.
     */
    @JvmName("shjfigxgoyocixho")
    public suspend
    fun mechanism(argument: suspend AddRemoveReplicaScalingMechanismArgsBuilder.() -> Unit) {
        val toBeMapped = AddRemoveReplicaScalingMechanismArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.mechanism = mapped
    }

    /**
     * @param value The name of the auto scaling policy.
     */
    @JvmName("pbmtqowhugoegwgl")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Determines when auto scaling operation will be invoked.
     */
    @JvmName("eijkskmyprqsgwii")
    public suspend fun trigger(`value`: AverageLoadScalingTriggerArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.trigger = mapped
    }

    /**
     * @param argument Determines when auto scaling operation will be invoked.
     */
    @JvmName("fijdqifesqaprayp")
    public suspend fun trigger(argument: suspend AverageLoadScalingTriggerArgsBuilder.() -> Unit) {
        val toBeMapped = AverageLoadScalingTriggerArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.trigger = mapped
    }

    internal fun build(): AutoScalingPolicyArgs = AutoScalingPolicyArgs(
        mechanism = mechanism ?: throw PulumiNullFieldException("mechanism"),
        name = name ?: throw PulumiNullFieldException("name"),
        trigger = trigger ?: throw PulumiNullFieldException("trigger"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/servicefabricmesh/kotlin/inputs/AutoScalingPolicyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicefabricmesh.kotlin.inputs

import com.pulumi.azurenative.servicefabricmesh.inputs.AutoScalingPolicyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Describes the auto scaling policy
 * @property mechanism The mechanism that is used to scale when auto scaling operation is invoked.
 * @property name The name of the auto scaling policy.
 * @property trigger Determines when auto scaling operation will be invoked.
 */
public data class AutoScalingPolicyArgs(
    public val mechanism: Output<AddRemoveReplicaScalingMechanismArgs>,
    public val name: Output<String>,
    public val trigger: Output<AverageLoadScalingTriggerArgs>,
) : ConvertibleToJava<com.pulumi.azurenative.servicefabricmesh.inputs.AutoScalingPolicyArgs> {
    override fun toJava(): com.pulumi.azurenative.servicefabricmesh.inputs.AutoScalingPolicyArgs =
        com.pulumi.azurenative.servicefabricmesh.inputs.AutoScalingPolicyArgs.builder()
            .mechanism(mechanism.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .name(name.applyValue({ args0 -> args0 }))
            .trigger(trigger.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [AutoScalingPolicyArgs].
 */
@PulumiTagMarker
public class AutoScalingPolicyArgsBuilder internal constructor() {
    private var mechanism: Output<AddRemoveReplicaScalingMechanismArgs>? = null

    private var name: Output<String>? = null

    private var trigger: Output<AverageLoadScalingTriggerArgs>? = null

    /**
     * @param value The mechanism that is used to scale when auto scaling operation is invoked.
     */
    @JvmName("gyjrtahoruhqnxxs")
    public suspend fun mechanism(`value`: Output<AddRemoveReplicaScalingMechanismArgs>) {
        this.mechanism = value
    }

    /**
     * @param value The name of the auto scaling policy.
     */
    @JvmName("gfesycofwyyyfgwh")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Determines when auto scaling operation will be invoked.
     */
    @JvmName("jfpsrttfgbbykvdd")
    public suspend fun trigger(`value`: Output<AverageLoadScalingTriggerArgs>) {
        this.trigger = value
    }

    /**
     * @param value The mechanism that is used to scale when auto scaling operation is invoked.
     */
    @JvmName("rklkfgfhdjfutalv")
    public suspend fun mechanism(`value`: AddRemoveReplicaScalingMechanismArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.mechanism = mapped
    }

    /**
     * @param argument The mechanism that is used to scale when auto scaling operation is invoked.
     */
    @JvmName("udsiweivgsifjldv")
    public suspend
    fun mechanism(argument: suspend AddRemoveReplicaScalingMechanismArgsBuilder.() -> Unit) {
        val toBeMapped = AddRemoveReplicaScalingMechanismArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.mechanism = mapped
    }

    /**
     * @param value The name of the auto scaling policy.
     */
    @JvmName("tmqgqpjfcsurcspn")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Determines when auto scaling operation will be invoked.
     */
    @JvmName("mocxmdsnxandidhn")
    public suspend fun trigger(`value`: AverageLoadScalingTriggerArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.trigger = mapped
    }

    /**
     * @param argument Determines when auto scaling operation will be invoked.
     */
    @JvmName("wrnncfknwalvusir")
    public suspend fun trigger(argument: suspend AverageLoadScalingTriggerArgsBuilder.() -> Unit) {
        val toBeMapped = AverageLoadScalingTriggerArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.trigger = mapped
    }

    internal fun build(): AutoScalingPolicyArgs = AutoScalingPolicyArgs(
        mechanism = mechanism ?: throw PulumiNullFieldException("mechanism"),
        name = name ?: throw PulumiNullFieldException("name"),
        trigger = trigger ?: throw PulumiNullFieldException("trigger"),
    )
}
